@@ -1,7 +1,6 @@
-from mlapp.managers import ModelManager
+from mlapp.managers import ModelManager, pipeline
 from sklearn.model_selection import train_test_split
 from mlapp.utils.automl import AutoMLPandas
-from mlapp.utils import pipeline
 
 
 class CrashCourseModelManager(ModelManager):
