@@ -9,7 +9,8 @@ from mlapp.integrations.aml.utils.run_class import load_config_from_string
 
 def init():
     global run_id
-    model_path = os.path.join(os.getenv('AZUREML_MODEL_DIR'))
+    model_path = os.path.join(os.getcwd(), os.getenv('AZUREML_MODEL_DIR'))
+    os.chdir('<LOCAL_ROOT_DIRECTORY_NAME>')
     output_dir = os.path.join(os.getcwd(), 'output')
     os.makedirs(output_dir, exist_ok=True)
     run_id = preprocess_deployment(model_path)
